@@ -1,4 +1,4 @@
-from typing import overload, Dict, Optional, List, TYPE_CHECKING
+from typing import overload, Dict, Optional, List, TYPE_CHECKING, Union, Sequence
 
 from .data import DocumentData, default_values
 from .mixins import AllMixins
@@ -6,8 +6,6 @@ from ..base import BaseDCType
 
 if TYPE_CHECKING:
     from ..types import ArrayType, StructValueType, DocumentContentType
-    from .. import DocumentArray
-    from ..score import NamedScore
 
 
 class Document(AllMixins, BaseDCType):
@@ -46,8 +44,8 @@ class Document(AllMixins, BaseDCType):
         parent_id: Optional[str] = None,
         granularity: Optional[int] = None,
         adjacency: Optional[int] = None,
-        buffer: Optional[bytes] = None,
-        blob: Optional['ArrayType'] = None,
+        blob: Optional[bytes] = None,
+        tensor: Optional['ArrayType'] = None,
         mime_type: Optional[str] = None,
         text: Optional[str] = None,
         content: Optional['DocumentContentType'] = None,
@@ -58,10 +56,10 @@ class Document(AllMixins, BaseDCType):
         location: Optional[List[float]] = None,
         embedding: Optional['ArrayType'] = None,
         modality: Optional[str] = None,
-        evaluations: Optional[Dict[str, 'NamedScore']] = None,
-        scores: Optional[Dict[str, 'NamedScore']] = None,
-        chunks: Optional['DocumentArray'] = None,
-        matches: Optional['DocumentArray'] = None,
+        evaluations: Optional[Dict[str, Dict[str, 'StructValueType']]] = None,
+        scores: Optional[Dict[str, Dict[str, 'StructValueType']]] = None,
+        chunks: Optional[Sequence['Document']] = None,
+        matches: Optional[Sequence['Document']] = None,
     ):
         ...
 
